barplot_function <- function(var_name, filename)
{
  pall <- c("red", "yellow", "blue", "green")
  #pall <- gray.colors(4, start = 0.3, end = 0.9, gamma = 2.2, alpha = NULL, rev = FALSE)
  png(paste(filename, '.png', sep = "", collapse = NULL), width = 460, height = 480)
  xx <- barplot(var_name, beside = FALSE, col = pall, ylim = c(0, 100), main = "")
  #text(x = xx, y = var_name + 0.04, label = round(var_name, 3))
  legend("topleft", colnames(var_name), fill = pall, cex = 0.75)
  dev.off()
}

build_input_dataset <- function()
{
  # working datasets
  component_types <- c()
  component_frames <- c()
  craft12_frames <- c()
  precision_frame <- c()
  recall_frame <- c()
  precision_craft12 <- c()
  recall_craft12 <- c()
  
  for(i in 1:length(unique(craft12$gui_mapper)))
  {
    cn <- unique(craft12$gui_mapper)[i] # name of gui_mapper
    
    # skip perfect
    if (cn == "perfect")
      next
    
    component_types[[i]] <- cn # add name to index
    
    # filter frame by gui_mapper name
    component_frames[[cn]] <- filter(all_noGT,gui_mapper==cn)
    craft12_frames[[cn]] <- filter(craft12,gui_mapper==cn)
    
    # calculate means
    precision_frame[[cn]] <- mean(component_frames[[cn]]$accuracy_precision, na.rm = TRUE) * 100
    precision_craft12[[cn]] <- mean(craft12_frames[[cn]]$accuracy_precision, na.rm = TRUE) * 100
    recall_frame[[cn]] <- mean(component_frames[[cn]]$accuracy_recall, na.rm = TRUE) * 100
    recall_craft12[[cn]] <- mean(craft12_frames[[cn]]$accuracy_recall, na.rm = TRUE) * 100
    
    # adjust craft12 for cumulative representation
    # precision_craft12[[cn]] <- precision_craft12[[cn]] - precision_frame[[cn]]
    # recall_craft12[[cn]] <- recall_craft12[[cn]] - recall_frame[[cn]]
  }
  
  return(t(cbind(precision_frame, recall_frame, precision_craft12, recall_craft12)))
}

create_images <- function()
{
  results <- build_input_dataset()
  precision <- results[!rownames(results) %in% c("recall_frame","recall_craft12"),]
  recall <- results[!rownames(results) %in% c("precision_frame","precision_craft12"),]
  barplot_function(precision,"precision")
  barplot_function(recall,"recall")
}

# DGstatic_recall <- c(DG0.8_filtered0.9$hit.set/(DG0.8_filtered0.9$hit.set+DG0.8_filtered0.9$miss.set))
# Naivestatic_recall <- c(Every0.8_filtered0.9$hit.set/(Every0.8_filtered0.9$hit.set+Every0.8_filtered0.9$miss.set))
# MPstatic_recall <- c(MP0.8_filtered0.9$hit.set/(MP0.8_filtered0.9$hit.set+MP0.8_filtered0.9$miss.set))
# PPMstatic_recall <- c(PPM0.8_filtered0.9$hit.set/(PPM0.8_filtered0.9$hit.set+PPM0.8_filtered0.9$miss.set))
# 
# fse <- final_framework_results_with_src[which(final_framework_results_with_src$gui_mapper=="FSE"),]
# cd <- final_framework_results_with_src[which(final_framework_results_with_src$gui_mapper=="CraftDroid"),]
# perfect <- final_framework_results_with_src[which(final_framework_results_with_src$gui_mapper=="Perfect"),]
# naive <- final_framework_results_with_src[which(final_framework_results_with_src$gui_mapper=="Random"),]
# 
# 
# 
# colors = c("red", "green", "blue", "black")
# metric = c("Precision", "Recall")
# algorithms = c("Naive", "FSE", "CraftDroid", "Perfect")
# count <- matrix(c(mean(naive$effectiveness_precision, na.rm = TRUE)*100, mean(fse$effectiveness_precision, na.rm = TRUE)*100, mean(cd$effectiveness_precision, na.rm = TRUE)*100,
#                   mean(perfect$effectiveness_precision, na.rm = TRUE)*100,
#                   
#                   mean(naive$effectiveness_recall, na.rm = TRUE)*100, mean(fse$effectiveness_recall, na.rm = TRUE)*100, mean(cd$effectiveness_recall, na.rm = TRUE)*100, 
#                   mean(perfect$effectiveness_recall, na.rm = TRUE)*100
# ), nrow=4, ncol=2)
# 
# x <- barplot(count, main = "Effectiveness Metrics", names.arg=metric, xlab="", ylab = "", ylim=range(pretty(c(0, 120))), cex.axis=0.8, col=colors, beside=TRUE)
# legend("topleft", algorithms, cex = 0.7, fill= colors)
# 
# 
# text(x, count, labels=as.character(round(count, 3)), pos = 3, cex=0.8 )
# 
# 
# fse <- final_accuracy_results[which(final_accuracy_results$gui_mapper=="FSE"),]
# cd <- final_accuracy_results[which(final_accuracy_results$gui_mapper=="CraftDroid"),]
# perfect <- final_accuracy_results[which(final_accuracy_results$gui_mapper=="Perfect"),]
# naive <- final_accuracy_results[which(final_accuracy_results$gui_mapper=="Random"),]
# 
# 
# colors = c("red", "green", "blue", "black")
# metric = c("Precision", "Recall")
# algorithms = c("FSE", "CraftDroid", "Perfect", "Naive")
# count <- matrix(c(mean(fse$accuracy_precision.x, na.rm = TRUE)*100, mean(cd$accuracy_precision.x, na.rm = TRUE)*100, mean(perfect$accuracy_precision, na.rm = TRUE)*100,
#                   mean(naive$accuracy_precision.x, na.rm = TRUE)*100,
#                   mean(fse$accuracy_recall.x, na.rm = TRUE)*100, mean(cd$accuracy_recall.x, na.rm = TRUE)*100, mean(perfect$accuracy_recall, na.rm = TRUE)*100,
#                   mean(naive$accuracy_recall.x, na.rm = TRUE)*100), nrow=4, ncol=2)
# 
# x <- barplot(count, main = "Accuracy Metrics", names.arg=metric, xlab="", ylab = "", ylim=range(pretty(c(0, 120))), cex.axis=0.8, col=colors, beside=TRUE)
# legend("topleft", algorithms, cex = 0.7, fill= colors)
# 
# 
# text(x, count, labels=as.character(round(count, 3)), pos = 3, cex=0.7 )
