library(corrplot)
library(RColorBrewer)
library(dplyr)

final_all_cor <- final_all %>% select(correct_percentage, incorrect_percentage, missed_percentage, nonExist_percentage, accuracy, accuracy_precision, accuracy_recall, distance, reduction, num_src)
M <-cor(na.omit( final_all_cor ))
corrplot(M, type="upper", order="hclust",
         col=brewer.pal(n=8, name="RdYlBu"))


#This script is used to calculate Spearman and Pearson correlation coefficients btetween test lengths and metrics(fidelity precision&recall, 
#effectiveness precision&recall)

#First, we draw a plot to see what type of relationship do the metrics and test_length have 
plot(shopping_all$accuracy_precision, shopping_all$num_src)
plot(shopping_all$accuracy_recall, shopping_all$num_src)
plot(shopping_all$distance, shopping_all$num_gt)
plot(shopping_all$reduction, shopping_all$num_gt)

#then we calculate the fitting correlation coefficient
library(gridExtra)
spearman_accuracy_precision <- cor.test(all$accuracy_precision, all$reduction, method="spearman")
pearson_accuracy_precision <- cor.test(all$accuracy_precision, all$reduction, method="pearson")

spearman_accuracy_recall <- cor.test(all$accuracy_recall, all$reduction, method="spearman")
pearson_accuracy_recall <- cor.test(all$accuracy_recall, all$reduction, method="pearson")


correlation_mettrics <- matrix(c(round(spearman_accuracy_precision$estimate, 3), round(pearson_accuracy_precision$estimate, 3), round(spearman_accuracy_recall$estimate, 3),  
                                 round(pearson_accuracy_recall$estimate, 3), 
                                 round(spearman_accuracy_precision$p.value, 5), 
                                 round(pearson_accuracy_precision$p.value, 5), round(spearman_accuracy_recall$p.value, 5), round(pearson_accuracy_recall$p.value, 3), 
                                 ), ncol=8, byrow=TRUE)

colnames(correlation_mettrics) <- c("S_Accuracy_Prec", "P_Accuracy_Prec", "S_Accuracy_Recall", "P_Accuracy_Recall")
rownames(correlation_mettrics) <- c("Estimate", "P-value")
pdf("correlation_mettrics.pdf", height=50*nrow(correlation_mettrics), width=200*ncol(correlation_mettrics))
e <- tableGrob(correlation_mettrics)
grid.arrange(e)
dev.off()



