# base sets
gui_mapper_list <- unique(all$gui_mapper)
news_per_gui_mapper <- list()
shopping_per_gui_mapper <- list()
for(val in gui_mapper_list)
{
  news_per_gui_mapper[[val]] <- filter(news_all,gui_mapper==val)
  shopping_per_gui_mapper[[val]] <- filter(shopping_all,gui_mapper==val)
}

# thresholds
news_accuracy_deciles <- list()
shopping_accuracy_deciles <- list()
for(val in gui_mapper_list)
{
  news_accuracy_deciles[[val]] <- quantile(news_per_gui_mapper[[val]]$accuracy, na.rm=TRUE, seq(0,1,0.1), names=FALSE)
  shopping_accuracy_deciles[[val]] <- quantile(shopping_per_gui_mapper[[val]]$accuracy, na.rm=TRUE, seq(0,1,0.1), names=FALSE)
}

# top results
news_top_results <- list()
shopping_top_results <- list()
for(val in gui_mapper_list)
{
  news_top_results[[val]] <- subset(filter(news_per_gui_mapper[[val]],accuracy >= news_accuracy_deciles[[val]][10]), select = -c(src_events,transferred,gt_events,correct,incorrect,missed,nonExist))
  shopping_top_results[[val]] <- subset(filter(shopping_per_gui_mapper[[val]],accuracy >= shopping_accuracy_deciles[[val]][10]), select = -c(src_events,transferred,gt_events,correct,incorrect,missed,nonExist))
}

# bottom results
news_bottom_results <- list()
shopping_bottom_results <- list()
for(val in gui_mapper_list)
{
  news_bottom_results[[val]] <- subset(filter(news_per_gui_mapper[[val]],accuracy <= news_accuracy_deciles[[val]][1]), select = -c(src_events,transferred,gt_events,correct,incorrect,missed,nonExist))
  shopping_bottom_results[[val]] <- subset(filter(shopping_per_gui_mapper[[val]],accuracy <= shopping_accuracy_deciles[[val]][1]), select = -c(src_events,transferred,gt_events,correct,incorrect,missed,nonExist))
}




# Ranking

# analysis method: this is what metrics to use in the analysis
metrics_list <- c("precision","recall","distance","reduction","num_correct","num_incorrect","num_missed","num_nonExist","correct_percentage","incorrect_percentage","missed_percentage","nonExist_percentage")

# thresholds: these are the decile thresholds of each data subset, for each metric
thresholds <- list()
for(val2 in metrics_list)
{
  thresholds[[val2]] <- quantile(as.data.frame(app_pairs_merged[,val2]),na.rm=TRUE,seq(0,1,0.1),names=FALSE)
}

# results
exploration_results <- list()
for(val2 in metrics_list)
{
  exploration_results[[val2]] <- list()
  for(i in 1:10)
  {
    aux_frame <- filter(app_pairs_merged,between(get(val2),thresholds[[val2]][i],thresholds[[val2]][i+1]))
    exploration_results[[val2]][[i]] <- subset(aux_frame,select=c("source","target",metrics_list,"number"))
  }
}






# Ranking by gui_mapper_method

# grouping method: this is what data is being analysed
gui_mapper_list <- unique(final_all$gui_mapper)

# analysis method: this is what metrics to use in the analysis
metrics_list <- c("accuracy_precision","accuracy_recall","distance","reduction")

# grouped data: these are auxiliary sets to calculate the thresholds
all_by_gui_mapper <- list()
for(val in gui_mapper_list)
{
  all_by_gui_mapper[[val]] <- filter(final_all,gui_mapper==val)
}

# thresholds: these are the decile thresholds of each data subset, for each metric
thresholds <- list()
for(val1 in gui_mapper_list)
{
  thresholds[[val1]] <- list()
  for(val2 in metrics_list)
  {
    thresholds[[val1]][[val2]] <- quantile(all_by_gui_mapper[[val1]][,val2],na.rm=TRUE,seq(0,1,0.1),names=FALSE)
  }
}

# results
exploration_results <- list()
for(val1 in gui_mapper_list)
{
  exploration_results[[val1]] <- list()
  for(val2 in metrics_list)
  {
    exploration_results[[val1]][[val2]] <- list()
    for(i in 1:10)
    {
      aux_frame <- filter(all_by_gui_mapper[[val1]],between(get(val2),thresholds[[val1]][[val2]][i],thresholds[[val1]][[val2]][i+1]))
      exploration_results[[val1]][[val2]][[i]] <- subset(aux_frame,select=c("method","source","target",metrics_list))
    }
  }
}
